darkhistory.physics — DarkHistory documentation

# darkhistory.physics

Physics functions as well as constants.

Throughout DarkHistory, we choose cm, s and eV as our system of units. Masses and temperatures are also given in eV. Particle Data Group central values [1] are used for constants, while cosmological parameters are set to the central values of the Planck 2018 baseline TT,TE,EE+lowE+lensing [2].

## Fundamental Constants

Attributes

`mp` | Proton mass in eV.
`me` | Electron mass in eV.
`mHe` | Helium nucleus mass in eV.
`hbar` | hbar in eV s.
`c` | Speed of light in cm s-1.
`kB` | Boltzmann constant in eV K-1.
`alpha` | Fine structure constant.
`ele` | Electron charge in coulombs.
`mass` | Masses of Standard Model particles.
`thomson_xsec` | Thomson cross section in cm2.
`stefboltz` | Stefan-Boltzmann constant in eV-3 cm-2 s-1.
`ele_rad` | Classical electron radius in cm.
`ele_compton` | Electron Compton wavelength in cm.

## Cosmology

Attributes

`h` | h parameter.
`H0` | Hubble parameter today in s-1.
`omega_m` | Omega of all matter today.
`omega_rad` | Omega of radiation today.
`omega_lambda` | Omega of dark energy today.
`omega_baryon` | Omega of baryons today.
`omega_DM` | Omega of dark matter today.
`rho_crit` | Critical density of the universe in eV cm-3.
`rho_DM` | DM density in eV cm-3.
`rho_baryon` | Baryon density in eV cm-3.
`nB` | Baryon number density in eV cm-3.
`nH` | Atomic hydrogen number density in cm-3.
`nHe` | Atomic helium number density in cm-3.
`nA` | Hydrogen and helium number density in cm-3.
`chi` | Ratio of helium to hydrogen nuclei.
`YHe` | Helium abundance by mass.

Functions

`hubble`(rs[, H0, omega_m, omega_rad, …]) | Hubble parameter in s-1.
`dtdz`(rs[, H0, omega_m, omega_rad, omega_lambda]) | dt/dz in s.
`TCMB`(rs) | CMB temperature in eV.
`CMB_N_density`(T) | CMB number density in cm-3.
`CMB_eng_density`(T) | CMB energy density in eV cm-3.
`CMB_spec`(eng, temp) | CMB spectrum in number of photons cm-3 eV-1.
`Tm_std`(rs) | Baseline Tm value.
`xHII_std`(rs) | Baseline nHII/nH value.
`xHeII_std`(rs) | Baseline nHeII/nH value.
`get_optical_depth`(rs_vec, xe_vec) | Computes the optical depth given an ionization history.
`inj_rate`(inj_type, rs[, mDM, sigmav, lifetime]) | Dark matter annihilation/decay energy injection rate.
`struct_boost_func`([model, model_params]) | Structure formation boost factor 1+B(z).

## Atomic and Optical Physics

Attributes

`rydberg` | Ionization potential of ground state hydrogen in eV.
`lya_eng` | Lyman alpha transition energy in eV.
`lya_freq` | Lyman alpha transition frequency in Hz.
`width_2s1s_H` | Hydrogen 2s to 1s decay width in s-1.
`bohr_rad` | Bohr radius in cm.
`He_ion_eng` | Energy needed to singly ionize neutral He in eV.
`He_exc_lambda` | HeI n=1 to n=2 excitation wavelength in cm.
`He_exc_eng` | HeI n=1 to n=2 excitation energies in eV.
`A_He_21p` | Einstein coefficient for 21p \(\to\) 1s decay in s-1.
`A_He_23P1` | Einstein coefficient for 23P1 \(\to\) 1s decay in s-1.
`width_21s_1s_He` | Width of He 21s \(\to\) 1s decay in s-1.

Functions

`alpha_recomb`(T_m, species) | Case-B recombination coefficient.
`beta_ion`(T_rad, species) | Case-B photoionization coefficient.
`peebles_C`(xHII, rs) | Hydrogen Peebles C coefficient.
`C_He`(xHII, xHeII, rs, species) | Helium C coefficients.
`xe_Saha`(rs, species) | Saha equilibrium ionization value for H and He.
`d_xe_Saha_dz`(rs, species) | z-derivative of the Saha equilibrium ionization value.
`photo_ion_rate`(rs, eng, xH, xe[, atom]) | Photoionization rate in cm-3 s-1.
`photo_ion_xsec`(eng, species) | Photoionization cross section in cm2.
`coll_exc_xsec`(eng[, species]) | e-e collisional excitation cross section in cm2.
`coll_ion_sec_elec_spec`(in_eng, eng[, species]) | Secondary electron spectrum after collisional ionization.
`coll_ion_xsec`(eng[, species]) | e-e collisional ionization cross section in cm2.
`elec_heating_engloss_rate`(eng, xe, rs) | Electron energy loss rate of electrons due to Coulomb heating in eV s-1.

Footnotes

[1] | Aghanim et al. [Planck Collaboration], “Planck 2018 results. VI. Cosmological parameters,” arXiv:1807.06209 [astro-ph.CO]

[2] | Tanabashi et al. (Particle Data Group), Phys. Rev. D 98, 030001 (2018).

### Table of Contents

- darkhistory.physics
  - Fundamental Constants
  - Cosmology
  - Atomic and Optical Physics

#### Previous topic

darkhistory

#### Next topic

darkhistory.physics.mp

### This Page

Show Source